==> downloads.html?file=gigkalender_v1.2.61_059.zip: gigkalender/calendar/backend_delGig.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
      echo '<p class="Headline">'.$L_Headline14.'</p>';
      if ( !IsUserAdmin() ) { echo $L_015; }
      else
      {
        // Inhalt hier einfügen
          if (isset($_POST['delGig']))
      	 {
        	   if ($_POST['delGig']==$L_Button23)
        	   {
              $id = $_POST['id'];
              $GigDate = getGigVarFromGigID ($id, 'GigDate');
              // Datensatz-L&ouml;schvorgang festlegen
              $SQL_Befehl = "DELETE FROM ".$prefix."gigs WHERE GigID = '$id'";

              // Datensatz-L&ouml;schvorgang durchf&uuml;hren
              $resultat = mysql_db_query($db_name, $SQL_Befehl);

              if ($resultat)
              {
                deleteFileInCache($GigDate);
                echo $L_039;
              }
              else { echo "Gig konnte nicht gelöscht werden!<br />"; }
        	   }
        	   if ($_POST['delGig']==$L_Button24)
        	   {
              echo $L_038;
        	   }
      	 }
      	 else
      	 {
        	   echo '
              </head>
              <body>
        	   ';
        	   echo $L_037.'<br /><br />';
        	   $id = $_GET['id'];
        	   echo '
              <form method="post" action="index.php?submenue=calendar&inhalt=backend_delGig">
                <fieldset>
                  <input name="delGig" id="delGig" type="submit" value="'.$L_Button23.'" class="button">
                  <input name="delGig" id="delGig" type="submit" value="'.$L_Button24.'" class="button">
                  <input name="id" id="id" type="hidden" value="'.$id.'">
                  <input type="hidden" name="http-equiv" value="backend_showAllGigs">
                </fieldset>
        	     </form>
            ';
      	 }
        // Inhalt zuende
      }
    ?>

==> downloads.html?file=gigkalender_v1.2.64.zip: gigkalender/calendar/backend_delGig.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
      echo '<p class="Headline">'.$L_Headline14.'</p>';
      if ( !IsUserAdmin() ) { echo $L_015; }
      else
      {
        // Inhalt hier einfügen
          if (isset($_POST['delGig']))
      	 {
        	   if ($_POST['delGig']==$L_Button23)
        	   {
              $id = $_POST['id'];
              $GigDate = getGigVarFromGigID ($id, 'GigDate');
              // Datensatz-L&ouml;schvorgang festlegen
              $SQL_Befehl = "DELETE FROM ".$prefix."gigs WHERE GigID = '$id'";

              // Datensatz-L&ouml;schvorgang durchf&uuml;hren
              $resultat = mysql_db_query($db_name, $SQL_Befehl);

              if ($resultat)
              {
                deleteFileInCache($GigDate);
                echo $L_039;
              }
              else { echo "Gig konnte nicht gelöscht werden!<br />"; }
        	   }
        	   if ($_POST['delGig']==$L_Button24)
        	   {
              echo $L_038;
        	   }
      	 }
      	 else
      	 {
        	   echo '
              </head>
              <body>
        	   ';
        	   echo $L_037.'<br /><br />';
        	   $id = $_GET['id'];
        	   echo '
              <form method="post" action="index.php?submenue=calendar&inhalt=backend_delGig" accept-charset="UTF-8">
                <fieldset>
                  <input name="delGig" id="delGig" type="submit" value="'.$L_Button23.'" class="button">
                  <input name="delGig" id="delGig" type="submit" value="'.$L_Button24.'" class="button">
                  <input name="id" id="id" type="hidden" value="'.$id.'">
                  <input type="hidden" name="http-equiv" value="backend_showAllGigs">
                </fieldset>
        	     </form>
            ';
      	 }
        // Inhalt zuende
      }
    ?>
